@@ -119,7 +119,7 @@ class Terncy:
         self._pending_requests = {}
         self._event_handler = None
 
-    def is_connected(self, handler):
+    def is_connected(self):
         return self._connection is not None
 
     def register_event_handler(self, handler):
